_itertools

package
v0.12.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 15, 2026 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var AccumulateType = objects.NewType("accumulate", []*objects.Type{objects.ObjectType()})

AccumulateType is itertools.accumulate.

CPython: Modules/itertoolsmodule.c:3080 accumulate_spec

var BatchedType = objects.NewType("batched", []*objects.Type{objects.ObjectType()})

BatchedType is itertools.batched.

CPython: Modules/itertoolsmodule.c:264 batched_spec

var ChainType = objects.NewType("chain", []*objects.Type{objects.ObjectType()})

ChainType is itertools.chain.

CPython: Modules/itertoolsmodule.c:1964 chain_spec

var CombinationsType = objects.NewType("combinations", []*objects.Type{objects.ObjectType()})

CombinationsType is itertools.combinations.

CPython: Modules/itertoolsmodule.c:2439 combinations_spec

var CombinationsWithReplacementType = objects.NewType("combinations_with_replacement",
	[]*objects.Type{objects.ObjectType()})

CombinationsWithReplacementType is itertools.combinations_with_replacement.

CPython: Modules/itertoolsmodule.c:2677 cwr_spec

var CompressType = objects.NewType("compress", []*objects.Type{objects.ObjectType()})

CompressType is itertools.compress.

CPython: Modules/itertoolsmodule.c:3216 compress_spec

var CountType = objects.NewType("count", []*objects.Type{objects.ObjectType()})

CountType is itertools.count.

CPython: Modules/itertoolsmodule.c:3581 count_spec

var CycleType = objects.NewType("cycle", []*objects.Type{objects.ObjectType()})

CycleType is itertools.cycle.

CPython: Modules/itertoolsmodule.c:1258 cycle_spec

var DropwhileType = objects.NewType("dropwhile", []*objects.Type{objects.ObjectType()})

DropwhileType is itertools.dropwhile.

CPython: Modules/itertoolsmodule.c:1382 dropwhile_spec

var FilterfalseType = objects.NewType("filterfalse", []*objects.Type{objects.ObjectType()})

FilterfalseType is itertools.filterfalse.

CPython: Modules/itertoolsmodule.c:3339 filterfalse_spec

var GroupbyType = objects.NewType("groupby", []*objects.Type{objects.ObjectType()})

GroupbyType is itertools.groupby.

CPython: Modules/itertoolsmodule.c:593 groupby_spec

var GrouperType = objects.NewType("_grouper", []*objects.Type{objects.ObjectType()})

GrouperType is itertools._grouper.

CPython: Modules/itertoolsmodule.c:713 _grouper_spec

var IsliceType = objects.NewType("islice", []*objects.Type{objects.ObjectType()})

IsliceType is itertools.islice.

CPython: Modules/itertoolsmodule.c:1692 islice_spec

var PairwiseType = objects.NewType("pairwise", []*objects.Type{objects.ObjectType()})

PairwiseType is itertools.pairwise.

CPython: Modules/itertoolsmodule.c:417 pairwise_spec

var PermutationsType = objects.NewType("permutations", []*objects.Type{objects.ObjectType()})

PermutationsType is itertools.permutations.

CPython: Modules/itertoolsmodule.c:2947 permutations_spec

var ProductType = objects.NewType("product", []*objects.Type{objects.ObjectType()})

ProductType is itertools.product.

CPython: Modules/itertoolsmodule.c:2222 product_spec

var RepeatType = objects.NewType("repeat", []*objects.Type{objects.ObjectType()})

RepeatType is itertools.repeat.

CPython: Modules/itertoolsmodule.c:3711 repeat_spec

var StarmapType = objects.NewType("starmap", []*objects.Type{objects.ObjectType()})

StarmapType is itertools.starmap.

CPython: Modules/itertoolsmodule.c:1801 starmap_spec

var TakewhileType = objects.NewType("takewhile", []*objects.Type{objects.ObjectType()})

TakewhileType is itertools.takewhile.

CPython: Modules/itertoolsmodule.c:1500 takewhile_spec

var TeeType = objects.NewType("_tee", []*objects.Type{objects.ObjectType()})

TeeType is itertools._tee.

CPython: Modules/itertoolsmodule.c:1080 tee_spec

var TeedataType = objects.NewType("_tee_dataobject", []*objects.Type{objects.ObjectType()})

TeedataType is itertools._tee_dataobject.

CPython: Modules/itertoolsmodule.c:924 teedataobject_spec

var ZipLongestType = objects.NewType("zip_longest", []*objects.Type{objects.ObjectType()})

ZipLongestType is itertools.zip_longest.

CPython: Modules/itertoolsmodule.c:3921 ziplongest_spec

Functions

This section is empty.

Types

type Accumulate

type Accumulate struct {
	objects.Header
	// contains filtered or unexported fields
}

Accumulate is accumulateobject.

CPython: Modules/itertoolsmodule.c:2958 accumulateobject

type Batched

type Batched struct {
	objects.Header
	// contains filtered or unexported fields
}

Batched is batchedobject: iterate over an underlying iterator and emit tuples of at most n consecutive values. With strict=True a trailing short batch raises ValueError.

CPython: Modules/itertoolsmodule.c:100 batchedobject

type Chain

type Chain struct {
	objects.Header
	// contains filtered or unexported fields
}

Chain is chainobject: walk through a stream of iterables.

CPython: Modules/itertoolsmodule.c:1812 chainobject

type Combinations

type Combinations struct {
	objects.Header
	// contains filtered or unexported fields
}

Combinations is combinationsobject.

CPython: Modules/itertoolsmodule.c:2233 combinationsobject

type Compress

type Compress struct {
	objects.Header
	// contains filtered or unexported fields
}

Compress is compressobject.

CPython: Modules/itertoolsmodule.c:3098 compressobject

type Count

type Count struct {
	objects.Header
	// contains filtered or unexported fields
}

Count is countobject. The two operating modes match CPython's fast/slow split: when both start and step are simple ints with step==1 we increment a Go int; otherwise everything goes through NumberAdd.

CPython: Modules/itertoolsmodule.c:3350 countobject

type Cwr

type Cwr struct {
	objects.Header
	// contains filtered or unexported fields
}

Cwr is cwrobject.

CPython: Modules/itertoolsmodule.c:2476 cwrobject

type Cycle

type Cycle struct {
	objects.Header
	// contains filtered or unexported fields
}

Cycle is cycleobject: replay the source iterator forever.

CPython: Modules/itertoolsmodule.c:1141 cycleobject

type Dropwhile

type Dropwhile struct {
	objects.Header
	// contains filtered or unexported fields
}

Dropwhile is dropwhileobject.

CPython: Modules/itertoolsmodule.c:1269 dropwhileobject

type Filterfalse

type Filterfalse struct {
	objects.Header
	// contains filtered or unexported fields
}

Filterfalse is filterfalseobject.

CPython: Modules/itertoolsmodule.c:3227 filterfalseobject

type Groupby

type Groupby struct {
	objects.Header
	// contains filtered or unexported fields
}

Groupby is groupbyobject: emit (key, _grouper) tuples for runs of adjacent equal keys.

CPython: Modules/itertoolsmodule.c:428 groupbyobject

type Grouper

type Grouper struct {
	objects.Header
	// contains filtered or unexported fields
}

Grouper is the sub-iterator handed back by groupby.

CPython: Modules/itertoolsmodule.c:603 _grouperobject

type Islice

type Islice struct {
	objects.Header
	// contains filtered or unexported fields
}

Islice is isliceobject: bounded random-access-style sub-iterator.

CPython: Modules/itertoolsmodule.c:1511 isliceobject

type Pairwise

type Pairwise struct {
	objects.Header
	// contains filtered or unexported fields
}

Pairwise yields overlapping pairs from the source iterator.

CPython: Modules/itertoolsmodule.c:275 pairwiseobject

type Permutations

type Permutations struct {
	objects.Header
	// contains filtered or unexported fields
}

Permutations is permutationsobject.

CPython: Modules/itertoolsmodule.c:2714 permutationsobject

type Product

type Product struct {
	objects.Header
	// contains filtered or unexported fields
}

Product is productobject.

CPython: Modules/itertoolsmodule.c:1975 productobject

type Repeat

type Repeat struct {
	objects.Header
	// contains filtered or unexported fields
}

Repeat is repeatobject.

CPython: Modules/itertoolsmodule.c:3592 repeatobject

type Starmap

type Starmap struct {
	objects.Header
	// contains filtered or unexported fields
}

Starmap is starmapobject.

CPython: Modules/itertoolsmodule.c:1703 starmapobject

type Takewhile

type Takewhile struct {
	objects.Header
	// contains filtered or unexported fields
}

Takewhile is takewhileobject.

CPython: Modules/itertoolsmodule.c:1393 takewhileobject

type Tee

type Tee struct {
	objects.Header
	// contains filtered or unexported fields
}

Tee is the user-visible iterator: a thin cursor into a Teedata chain.

CPython: Modules/itertoolsmodule.c:745 teeobject

type Teedata

type Teedata struct {
	objects.Header
	// contains filtered or unexported fields
}

Teedata is the per-link cache shared by Tee siblings.

CPython: Modules/itertoolsmodule.c:734 teedataobject

type ZipLongest

type ZipLongest struct {
	objects.Header
	// contains filtered or unexported fields
}

ZipLongest is ziplongestobject.

CPython: Modules/itertoolsmodule.c:3722 ziplongestobject

Jump to